import * as Messages from "/services/messages/messages.js";

let partyModel;

export function getPartyModel() {
  if (partyModel == null) {
    partyModel = new PartyModel();
  }
  return partyModel;
}

class PartyModel {
  constructor() {}

  async getParty(id) {
    if (this.parties == null) await this.refreshParties();
    let partyToGet;
    this.parties.forEach((party) => {
      if (party.ID == id) partyToGet = party;
    });
    return partyToGet;
  }

  async getParties() {
    if (this.parties == null) {
      try {
        const response = await fetch("/api/Party/", {
          method: "GET",
          headers: new Headers({
            "XSRF-Token": this.current_user.xsrftoken,
          }),
        });
        if (response.status !== 200) {
          throw new Error(
            `Parties could not be fetched (status ${response.status})`
          );
        }
        this.parties = await response.json();
      } catch (e) {
        Messages.Show("is-warning", e.message);
        console.error(e);
      }
    }
    return this.parties;
  }

  async saveParty(method, ID, Name, Color) {
    try {
      const response = await fetch("/api/Party/" + ID, {
        method: method,
        headers: new Headers({
          "XSRF-Token": this.current_user.xsrftoken,
        }),
        body: JSON.stringify({
          ID: ID,
          Name: Name,
          Color: Color,
        }),
      });
      if (response.status !== 200) {
        throw new Error(
          `Party could not be updated or created (status ${response.status})`
        );
      }
      this.refreshParties();
      return await response.json();
    } catch (e) {
      Messages.Show("is-warning", e.message);
      console.error(e);
      return;
    }
  }

  async deleteParty(ID) {
    try {
      const response = await fetch("/api/Party/" + ID, {
        method: "delete",
        headers: new Headers({
          "XSRF-Token": this.current_user.xsrftoken,
        }),
      });
      if (response.status !== 200) {
        throw new Error(
          `Party could not be deleted (status ${response.status})`
        );
      }
      this.refreshParties();
    } catch (e) {
      Messages.Show("is-warning", e.message);
      console.error(e);
    }
  }

  async refreshParties() {
    this.parties = null;
    await this.getParties();
  }

  checkInputs(method, ID, Name) {
    if (method == "PUT" && ID == "") {
      Messages.Show(
        "is-warning",
        "Un erreur s'est produite lors de la mise à jour."
      );
      return false;
    }
    if (Name == "") {
      Messages.Show("is-warning", "Veuillez choisir un nom pour le parti");
      return false;
    }
    return true;
  }
}
